# TriangularMap

[![tests](https://github.com/robert-lieck/triangularmap/actions/workflows/tests.yml/badge.svg)](https://github.com/robert-lieck/triangularmap/actions/workflows/tests.yml)
[![codecov](https://codecov.io/gh/robert-lieck/triangularmap/branch/main/graph/badge.svg?token=XAUCWNS7II)](https://codecov.io/gh/robert-lieck/triangularmap)

![build](https://github.com/robert-lieck/triangularmap/workflows/build/badge.svg)
[![PyPI version](https://badge.fury.io/py/triangularmap.svg)](https://badge.fury.io/py/triangularmap)

[![docs](https://github.com/robert-lieck/triangularmap/actions/workflows/docs.yml/badge.svg)](https://robert-lieck.github.io/triangularmap/)
[![License: GPL v3](https://img.shields.io/badge/License-GPLv3-blue.svg)](https://www.gnu.org/licenses/gpl-3.0)
